import matplotlib.pyplot as plt
import pandas as pd
from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
from PyQt6.QtWidgets import QWidget, QVBoxLayout, QPushButton, QLabel, QTableWidget, QTextEdit, QHBoxLayout

def display_graphs(df, analytics_tab):
    """This function displayes updated graphs on the analytics tab based on patient refferral data"""
    if df is None or "referral" not in df.columns:
        return

    # Find patient_count_label before clearing widgets
    patient_count_label = None
    for i in reversed(range(analytics_tab.layout().count())):
        widget = analytics_tab.layout().itemAt(i).widget()
        if isinstance(widget, QLabel) and "Total Patients" in widget.text():
            patient_count_label = widget  # Store reference to patient count label
        else:
            widget.deleteLater()  # Remove only charts

    # If patient_count_label exists, update its text
    if patient_count_label:
        patient_count_label.setText(f"Total Patients: {len(df)}")
    else:
        patient_count_label = QLabel(f"Total Patients: {len(df)}")
        analytics_tab.layout().addWidget(patient_count_label)  # Readd if deleted

    # Add new graphs
    analytics_tab.layout().addWidget(create_pie_chart(df["referral"].value_counts()))
    analytics_tab.layout().addWidget(create_missing_data_chart(df))




def create_pie_chart(data):
    fig, ax = plt.subplots(figsize=(6, 4))
    labels = [f"{label} ({count})" for label, count in zip(data.index, data.values)]
    ax.pie(data.values, labels=labels, autopct='%1.1f%%', startangle=90, colors=["green", "red"])
    ax.set_title("Referral Distribution")
    return FigureCanvas(fig)

def create_missing_data_chart(df):
    missing_counts = df.replace("None", pd.NA).isna().sum()
    missing_counts = missing_counts[missing_counts > 0]

    fig, ax = plt.subplots(figsize=(10, 6))
    bars = ax.bar(missing_counts.index, missing_counts.values, color="blue")

    ax.set_xticks(range(len(missing_counts)))  
    ax.set_xticklabels(missing_counts.index.tolist(), rotation=30, ha='right', fontsize=9)

    for bar in bars:
        height = bar.get_height()
        ax.text(bar.get_x() + bar.get_width()/2, height, str(int(height)), ha='center', va='bottom', fontsize=10, color='black')

    ax.set_title("Patients Without Data")
    ax.set_ylabel("Number of Patients")

    return FigureCanvas(fig)
